function [signals, params] = simulate_data

% [signals] = simulate_data
%
% Makes a matrix signals with two rows containing [nTrials] trials
% containing phase-locked and non-phase-locked oscillations.
% 
% T.E.Gladwin, 2007

% parameters
params.Fs = 100;
params.trialTime_of_interest = 1;
params.interTrialInterval = 0.5;
params.filterBuffer = 0.8;
params.trialTimeTotal = params.trialTime_of_interest + 2 * params.filterBuffer + params.interTrialInterval;
params.nTrials = 40;
params.phase_locked_freq = 6;
params.non_phase_locked_freq = 14;
params.signal_t = 0:(1/params.Fs):(params.trialTime_of_interest);
params.randfactor = 0.2;
params.amps = [3.25 1.5];

% making the data
signals = [];
for iTrial = 1:params.nTrials,
    thisTrial = {};
    for n = 1:2,
        phaseShift = rand * 2 * pi;
        amp_envelop = sin(2 * pi * (0.5 / params.trialTime_of_interest) * params.signal_t);
        thisTrial{n} = params.randfactor * randn(size(params.signal_t));
        thisTrial{n} = thisTrial{n} + params.amps(1) * amp_envelop .* cos(2 * pi * params.phase_locked_freq * params.signal_t);
        thisTrial{n} = thisTrial{n} + params.amps(2) * amp_envelop .* cos(2 * pi * params.non_phase_locked_freq * params.signal_t + phaseShift);
    end;
    signals = [signals randn(2, params.filterBuffer * params.Fs)];
    signals = [signals [thisTrial{1}; thisTrial{2}] ];
    signals = [signals randn(2, params.filterBuffer * params.Fs)];
    signals = [signals randn(2, params.interTrialInterval * params.Fs)];
end;
params.total_t = 0:(1/params.Fs):(2 * params.filterBuffer + params.interTrialInterval + params.trialTime_of_interest);
params.samples_per_trial = floor(params.total_t(end) * params.Fs);
params.total_t = ((1:params.samples_per_trial) - 1) / params.Fs;

params.trial_starts = 1:params.samples_per_trial:length(signals(1, :));
