function [signals, params, ERA1, ERA2, PLV] = test_wavelets

% function [signals, params, ERA1, ERA2, PLV] = test_wavelets
%
% T.E.Gladwin, 2007

% simulate data

[signals, params] = simulate_data;
figure(1);
clf;
t_axis = params.total_t;
nTrials_to_plot = min(3, params.nTrials);
for iTrial = 1:nTrials_to_plot,
    subplot(nTrials_to_plot, 1, iTrial);
    s0 = 1 + (iTrial - 1) * params.samples_per_trial;
    s1 = s0 + params.samples_per_trial - 1;
    figure(1); plot(t_axis, signals(:, s0:s1)'); 
    if iTrial == 1,
        title('Examples of trials');
    end;
end;
xlim([t_axis(1) t_axis(end)]);

% get PLV for a phase-locked and non-phase-locked frequency
figure(2);
clf;
for n = 1:2,
    % consider phase-locked or non-phase-locked frequency
    if n == 1,
        freq_mid = params.phase_locked_freq;
    else,
        freq_mid = params.non_phase_locked_freq;
    end;

    % get complex convolutions for current centre-frequency (using 1 Hz
    % uncertainty as default)
    freq_sd = 1;
    [amp1, amp2, phase_difference] = wavelets(params.Fs, freq_mid, freq_sd, signals(1, :), signals(2, :));
    ERA1{n} = getERA(amp1, params.trial_starts, params.samples_per_trial);
    ERA2{n} = getERA(amp2, params.trial_starts, params.samples_per_trial);
    
    % get the PLV
    PLV{n} = getPLV(phase_difference, params.trial_starts, params.samples_per_trial);
    
    % plot inst. amplitude
    subplot(2, 2, 1 + (n - 1) * 2); 
    hold on;
    if n == 1,
        title('Amplitude for phase-locked frequency.');
    else,
        title('Amplitude for non-phase-locked frequency.');
    end;
    plot(t_axis, [ERA1{n} ERA2{n} ]);
    xlim([t_axis(1) t_axis(end)]);

    % plot PLV
    subplot(2, 2, 1 + (n - 1) * 2 + 1); 
    hold on;
    ylim([0, 1]);
    if n == 1,
        freqmid = params.phase_locked_freq;
        title('PLV for phase-locked frequency.');
    else,
        freqmid = params.non_phase_locked_freq;
        title('PLV for non-phase-locked frequency.');
    end;
    plot(t_axis, PLV{n});
    xlim([t_axis(1) t_axis(end)]);
end;
