function varargout = wavelets(varargin)

% function amp = wavelets(Fs, freq_mid, freq_sd, vector1)
% function [amp1, amp2, phase_difference] = wavelets(Fs, freq_mid, freq_sd, vector1, vector2)
%
% T.E.Gladwin, 2007

Fs = varargin{1};
freq_mid = varargin{2};
freq_sd = varargin{3};
vector1 = varargin{4};
if length(varargin) > 4,
    vector2 = varargin{5};
else
    vector2 = [];
end;
[realPart1, imPart1] = getComplexConvolutions(vector1, Fs, freq_mid, freq_sd);
varargout{1} = CC2Amp(realPart1, imPart1);
if ~isempty(vector2),
    [realPart2, imPart2] = getComplexConvolutions(vector2, Fs, freq_mid, freq_sd);
    varargout{2} = CC2Amp(realPart2, imPart2);
    varargout{3} = CC2PD(realPart1, imPart1, realPart2, imPart2);
end;

% Subfunctions

function [realPart, imPart] = getComplexConvolutions(signal, Fs, freq_mid, freq_sd)
a = 1;
b = my_Morlet('cos', freq_mid, freq_sd, Fs);
realPart = filter(b,a,signal) * (1 / Fs);
b = my_Morlet('sin', freq_mid, freq_sd, Fs);
imPart = filter(b,a,signal) * (1 / Fs);
shifter = ceil(length(b) / 2);
realPart(1:(end - shifter + 1)) = realPart(shifter:end);
realPart(1:shifter) = 0;
realPart((end - shifter):end) = 0;
imPart(1:(end - shifter + 1)) = imPart(shifter:end);
imPart(1:shifter) = 0;
imPart((end - shifter):end) = 0;

function wl = my_Morlet(type, freq_mid, freq_sd, Fs);
par = 7;
sigT = 1 / (2 * pi * freq_sd);
t = (-par * sigT):(1 / Fs):(par * sigT);
if strcmpi(type, 'cos') == 1,
    osc = cos(2 * pi * freq_mid * t);
else,
    osc = sin(2 * pi * freq_mid * t);
end;
g = Gaussian(t, sigT);
wl = g .* osc;
wl = wl * 2 / (sigT * sqrt(2 * pi));

function g = Gaussian(t, sigT);
g = exp((-t .^ 2) / (2 * sigT ^ 2));

function amp = CC2Amp(realPart, imPart)
amp = sqrt(imPart .^ 2 + realPart .^ 2);

function angle_diff = CC2PD(realPart_A, imPart_A, realPart_B, imPart_B)
% get the phases
angle_A = atan2(imPart_A, realPart_A);
angle_B = atan2(imPart_B, realPart_B);
% get the phase differences
angle_diff = angle_A - angle_B;
